@@ -5,7 +5,7 @@ use parent 'C::TinyCompiler::package';
 use Carp;
 
 BEGIN {
-	our $VERSION = '0.04';
+	our $VERSION = '0.05';
 	use XSLoader;
 	XSLoader::load 'C::TinyCompiler::Callable', $VERSION;
 }
@@ -336,6 +336,8 @@ sub build_Perl_invoker {
 	# unpacked on the Perl side, in the same order as the C function
 	# definition.
 	my $arg_list_string = '$' . join(', $', @{$funchash->{arg_names}});
+	my $sub_unpack_string = "my ($arg_list_string) = \@_";
+	$sub_unpack_string = '' if $arg_list_string eq '$';
 	my $N_args = scalar(@{$funchash->{arg_names}});
 	my $invoker_name = '_' . $funchash->{name} . '_invoker';
 	my $pack_string = '';
@@ -346,7 +348,7 @@ sub build_Perl_invoker {
 			# Make sure we have enough arguments
 			croak('$function_name expects $N_args arguments')
 				unless \@_ == $N_args;
-			my ($arg_list_string) = \@_;
+			$sub_unpack_string;
 			
 			# Build the list of values to pack. Arguments are packed in order
 			# of descending size in bytes, not necessarily the specified
@@ -628,6 +630,37 @@ pointer:
  #                     ^
  # No reference!       |
 
+=head2 Directly Passing an SV *
+
+It may be that you want to write a function that directly manipulates 
+an C<SV*>. For such a task, using XS::TCC is probably the better 
+TCC-related tool for this job. You can use C::TinyCompiler, though. 
+First, you will need to include C<C::TinyCompiler::Perl> in your compiler
+context. Then, your C function will have an C<SV*> in the argument list:
+
+ $context = C::TinyCompiler->new('::Perl', '::Callable');
+ $context->code('Body') = q{
+ C::TinyCompiler::Callable
+     void my_set_IV (SV * a, int b) {
+         sv_setiv(a, b);
+     }
+ };
+ $context->compile;
+
+Finally, when calling the function, I<you must pass a reference to the
+scalar that you want sent to the function>:
+
+ my $my_set_IV = $context->get_callable_subref('my_set_IV');
+ my $to_set;
+ 
+ # Set variable to 10
+ $my_set_IV->(\$to_set, 10);
+
+I know, this is annoying, but I couldn't find a way to get the original 
+SV to the C function. And if we can't get the original SV to the C 
+function, then the C function wouldn't be able to make any 
+modifications to the SV. And what's the fun in that?
+
 =head2 Working with Perl-level objects
 
 If you have Perl objects with data that you want to pass to a Callable
